/*
* This file is part of video-editor-ui
*
* Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies). All rights
* reserved.
*
* Contact: Kristiina Hietanen <Kristiina.Hietanen@nokia.com>
*
* This software, including documentation, is protected by copyright controlled
* by Nokia Corporation. All rights are reserved. Copying, including
* reproducing, storing, adapting or translating, any or all of this material
* requires the prior written consent of Nokia Corporation. This material also
* contains confidential information which may not be disclosed to others
* without the prior written consent of Nokia.
*
*/

import QtQuick 1.0
import com.nokia.meego 1.0
import "UIConstants.js" as UI

Menu {
    property int selectedIndex: -1
    property string selectedAudioFile: ""

    property int original: 0
    property int mute: 1
    property int replace: 3

    property int __previousIndex: -1

    MenuLayout {
        id: menu
        MenuItem { onClicked: { selectedIndex = 0 } }
        MenuItem { onClicked: { selectedIndex = 1 } }
        MenuItem { onClicked: { selectedIndex = 2 } }
    }

    MenuLayout {
        id: menu2
        visible: false
        MenuItem { onClicked: { selectedIndex = 0 } }
        MenuItem { onClicked: { selectedIndex = 1 } }
        MenuItem { onClicked: { selectedIndex = 2 } }
        MenuItem { onClicked: { selectedIndex = 3 } }
    }

    Component.onCompleted: {
        //% "!!Original audio"
            menu.menuChildren[0].text = qsTrId("qtn_vied_original_audio");
            //% "!!Mute"
            menu.menuChildren[1].text = qsTrId("qtn_vied_mute");
            //% "!!Select new audio file"
            menu.menuChildren[2].text = qsTrId("qtn_vied_select_audio_file");
            selectedIndex = 0;

            for (var i = 0; i < menu.menuChildren.length; i++) {
                menu2.menuChildren[i].text = menu.menuChildren[i].text;
            }
            menu2.menuChildren[3].style.inverted = true;
    }

    onSelectedIndexChanged: {
        updateDoneButton();
        if (selectedIndex == 0) {
            __audioButtonIcon = UI.AUDIO_BUTTON;
            selectedAudioFile = "";
        } else if (selectedIndex == 1) {
            __audioButtonIcon = UI.AUDIO_BUTTON_MUTED;
            selectedAudioFile = "";
        } else if (selectedIndex == 2) {
            openAudioFilesDialog();
            selectedIndex = __previousIndex;
            return;
        } else {
            __audioButtonIcon = UI.AUDIO_BUTTON_REPLACED;
        }
        menu.visible = (selectedIndex != 3);
        menu2.visible = (selectedIndex == 3);
        for (var i = 0; i < menu.menuChildren.length; i++) {
            menu.menuChildren[i].style.inverted = (i == selectedIndex);
        }
        __previousIndex = selectedIndex;
    }

    onSelectedAudioFileChanged: {
        menu2.menuChildren[3].text = selectedAudioFile;
        if (selectedAudioFile != "") {
            selectedIndex = 3;
        }
    }
}
